import React from 'react';
import { FormField, TypeAdapter, ValidationAdapter } from './Form';
import { FormInstance } from 'rc-field-form';
import InputAdapter from './adapters/InputAdapter';
import SelectAdapter from './adapters/SelectAdapter';
import TextareaAdapter from './adapters/TextareaAdapter';
import MultiSelectAdapter from './adapters/MultiSelectAdapter';
import ImagePickerAdapter from './adapters/ImagePickerAdapter';
import MultiSelectTreeAdapter from './adapters/MultiSelectTreeAdapter';

export default class CommonAdapters {
  static all(): TypeAdapter[] {
    return [
      {
        name: 'string',
        // eslint-disable-next-line react/display-name
        render: (field, props) => {
          return <InputAdapter {...props} field={field} />;
        },
      },
      {
        name: 'textarea',
        // eslint-disable-next-line react/display-name
        render: (field: FormField, props: any) => {
          return <TextareaAdapter {...props} field={field} />;
        },
      },
      {
        name: 'select',
        // eslint-disable-next-line react/display-name
        render: (field: FormField, props: any) => {
          return <SelectAdapter {...props} field={field} />;
        },
      },
      {
        name: 'multi-select',
        // eslint-disable-next-line react/display-name
        render: (field: FormField, props: any) => {
          return <MultiSelectAdapter {...props} field={field} />;
        },
      },
      {
        name: 'multi-select-tree',
        // eslint-disable-next-line react/display-name
        render: (field: FormField, props: any) => {
          return <MultiSelectTreeAdapter {...props} field={field} />;
        },
      },
      {
        name: 'image-picker',
        // eslint-disable-next-line react/display-name
        render: (field: FormField, props: any) => {
          return <ImagePickerAdapter {...props} field={field} />;
        },
      },
    ];
  }

  static allValidators(): ValidationAdapter[] {
    return [
      {
        name: 'equals',
        message: 'Should be equals',
        validator: async (rule: any, value: any, form: FormInstance) => {
          if (form.getFieldValue(rule.to) !== value) {
            throw Error('Not equal');
          }
        },
      },
    ];
  }
}
