import React, { FC } from 'react';
import {
  Icon,
  Input as InputX,
  Item,
  Label,
  NativeBase,
  RnViewStyleProp,
  Text,
} from 'native-base';
import { styles } from './styles';

type Props = NativeBase.Input & {
  type?: 'material' | 'material-black' | 'primary' | 'bordered';
  inputStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  iconName?: string;
  iconProps?: NativeBase.Icon;
  labelProps?: NativeBase.Label;
  inputProps?: NativeBase.Input;
  validationInfo?: string[];
  // children?: ReactNode;
};
export const Input: FC<Props> = (props: Props) => {
  const {
    type,
    label,
    labelProps,
    iconName,
    iconProps,
    style,
    inputStyle,
    validationInfo,
  } = props;
  const propsX = { ...props };
  propsX.style = inputStyle;
  delete propsX.labelProps;
  delete propsX.iconProps;
  delete propsX.type;
  delete propsX.label;
  delete propsX.inputStyle;

  const renderElement = (
    itemStyle?: any,
    inputStyleX?: any,
    labelStyle?: any,
    iconStyle?: any
  ) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...itemStyle, ...(style as object) }
            : itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}
        <Item style={inputStyleX}>
          <InputX
            placeholderTextColor={'#C4C4C4'}
            {...propsX}
            style={inputStyle ? { ...inputStyleX, ...inputStyle } : inputStyleX}
          />
          {iconName && (
            <Icon
              active
              {...iconProps}
              name={iconName}
              style={
                labelProps?.style
                  ? { ...iconStyle, ...(iconProps?.style as object) }
                  : iconStyle
              }
            />
          )}
        </Item>
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(
        styles.itemStyleMaterial,
        styles.material,
        styles.textMaterial,
        styles.iconWhite
      );
    case 'material-black':
      return renderElement(
        styles.itemStyleMaterialBlack,
        styles.materialBlack,
        { ...styles.textMaterial, color: 'black' },
        styles.iconDefault
      );
    case 'bordered':
      return renderElement(
        styles.itemStyle,
        { ...styles.bordered, borderBottomWidth: 0.7 },
        {
          ...styles.textDefault,
          color: '#979797',
        }
      );
    default:
      return renderElement(
        styles.itemStyle,
        styles.default,
        styles.textDefault
      );
  }
};
